"use strict";
/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Progress = void 0;
const util = require("util");
const core_1 = require("@oclif/core");
const kit_1 = require("@salesforce/kit");
const _1 = require(".");
/**
 * Class for display a progress bar to the console. Will automatically be suppressed if the --json flag is present.
 */
class Progress extends _1.UxBase {
    constructor(outputEnabled) {
        super(outputEnabled);
    }
    /**
     * Set the total number of expected components.
     */
    setTotal(total) {
        this.total = total;
        this.bar.setTotal(total);
    }
    /**
     * Start the progress bar.
     */
    start(total, payload = {}, options = Progress.DEFAULT_OPTIONS) {
        const opts = Object.assign(Progress.DEFAULT_OPTIONS, options);
        opts.format = util.format(opts.format, opts.title);
        this.bar = core_1.CliUx.ux.progress({
            format: opts.format,
            barCompleteChar: opts.barCompleteChar,
            barIncompleteChar: opts.barIncompleteChar,
            linewrap: opts.linewrap,
        });
        this.bar.setTotal(total);
        // this.maybeNoop(() => startProgressBar(this.bar, total, payload));
        this.maybeNoop(() => {
            this._start(total, payload);
        });
    }
    /**
     * Update the progress bar.
     */
    update(num, payload = {}) {
        this.bar.update(num, payload);
    }
    /**
     * Update the progress bar with the final number and stop it.
     */
    finish(payload = {}) {
        this.bar.update(this.total, payload);
        this.bar.stop();
    }
    /**
     * Stop the progress bar.
     */
    stop() {
        this.bar.stop();
    }
    _start(total, payload = {}) {
        const start = kit_1.once((bar, t, p = {}) => {
            bar.start(t);
            if (Object.keys(p).length) {
                bar.update(0, p);
            }
        });
        start(this.bar, total, payload);
    }
}
exports.Progress = Progress;
Progress.DEFAULT_OPTIONS = {
    title: 'PROGRESS',
    format: '%s | {bar} | {value}/{total} Components',
    barCompleteChar: '\u2588',
    barIncompleteChar: '\u2591',
    linewrap: true,
};
//# sourceMappingURL=progress.js.map